#!/usr/bin/env python
# -*- coding: utf-8 -*-
from PyQt4.QtCore import *
from PyQt4.QtGui import *
from main import Main
import logging
import sys

try:
    import osso
    maemo = True
    #logging.warning("Maemo detected")
except:
    maemo = False
    #logging.info("Not Maemo")

if __name__ == "__main__":
    app = QApplication (sys.argv)

    #app.setOrganizationName('mmlado')
    app.setApplicationName('PeQersi')
    app.setApplicationVersion('0.0.0')

    main = Main(maemo = maemo)
    main.show()

    sys.exit (app.exec_ ())

